==> node-v0.5.9.tar.gz: node-v0.5.9/test/simple/test-http-head-request.js <==
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.

var common = require('../common');
var assert = require('assert');
var http = require('http');
var util = require('util');


var body = 'hello world\n';

var server = http.createServer(function(req, res) {
  common.error('req: ' + req.method);
  res.writeHead(200, {'Content-Length': body.length});
  res.end();
  server.close();
});

var gotEnd = false;

server.listen(common.PORT, function() {
  var request = http.request({
    port: common.PORT,
    method: 'HEAD',
    path: '/'
  }, function(response) {
    common.error('response start');
    response.addListener('end', function() {
      common.error('response end');
      gotEnd = true;
    });
  });
  request.end();
});

process.addListener('exit', function() {
  assert.ok(gotEnd);
});

==> node-v0.9.4.tar.gz: node-v0.9.4/test/simple/test-http-head-request.js <==
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.

var common = require('../common');
var assert = require('assert');
var http = require('http');
var util = require('util');


var body = 'hello world\n';

var server = http.createServer(function(req, res) {
  common.error('req: ' + req.method);
  res.writeHead(200, {'Content-Length': body.length});
  res.end();
  server.close();
});

var gotEnd = false;

server.listen(common.PORT, function() {
  var request = http.request({
    port: common.PORT,
    method: 'HEAD',
    path: '/'
  }, function(response) {
    common.error('response start');
    response.on('end', function() {
      common.error('response end');
      gotEnd = true;
    });
  });
  request.end();
});

process.on('exit', function() {
  assert.ok(gotEnd);
});
